darkhistory.low_energy.lowE_photons.kappa_DM — DarkHistory documentation

# darkhistory.low_energy.lowE_photons.kappa_DM

`darkhistory.low_energy.lowE_photons.` `kappa_DM`(photspec, xe)

  Compute kappa_DM of the modified tla.

  Parameters: | photspec : Spectrum object spectrum of photons. Assumed to be in dNdE mode. spec.toteng() should return Energy per baryon.
  Returns: | kappa_DM : float The added photoionization rate due to products of DM.

#### Previous topic

darkhistory.low_energy.lowE_photons.getf_ion

#### Next topic

darkhistory.spec

### This Page

Show Source